import React, { useState } from 'react'
import { Inertia } from '@inertiajs/inertia'
import { InertiaLink, usePage } from '@inertiajs/inertia-react'
import Layout from '@/Shared/Layout'
import SelectInput from '@/Shared/SelectInput'
import TextInput from '@/Shared/TextInput'
import Button from '@/Shared/Button'

const QuizEditForm = () => {
  const { quiz, errors } = usePage()

  const [values, setValues] = useState({
    title: quiz.title || '',
    type: quiz.type || '',
  })

  function handleChange(e) {
    const key = e.target.name
    const value = e.target.value
    setValues(values => ({
      ...values,
      [key]: value,
    }))
  }

  function handleSubmit(e) {
    e.preventDefault()
    Inertia.put(route('eventpal.quiz.update', quiz), values)
  }

  return (
    <div>
      <form onSubmit={handleSubmit}>
        <div className='form-panel'>
          <div className=''>
            <TextInput
              className='pb-3'
              label='Title'
              name='title'
              errors={errors.title}
              value={values.title}
              onChange={handleChange}
            />
            <SelectInput
              className='pb-3'
              label='Type'
              name='type'
              errors={errors.type}
              value={values.type}
              onChange={handleChange}
            >
              <option value='controlled'>Controlled</option>
            </SelectInput>
          </div>
        </div>
        <div className='page-actions'>
          <InertiaLink
            className='btn btn-light tw-float-left'
            href={route('eventpal.quiz.index')}
          >
            <span>
              <i className='fas fa-chevron-left' />
              Back to quiz list
            </span>
          </InertiaLink>
          <Button
            type='submit'
            value='Submit'
            icon='fas fa-check'
            className='btn btn-dark tw-float-right'
          />
        </div>
      </form>
    </div>
  )
}

// eslint-disable-next-line react/display-name
QuizEditForm.layout = page => (
  <Layout area='Quizzes' title='Edit Quiz'>
    {page}
  </Layout>
)

export default QuizEditForm
