import React, { useState } from 'react'
import { Inertia } from '@inertiajs/inertia'
import { InertiaLink, usePage } from '@inertiajs/inertia-react'
import Layout from '@/Shared/Layout'
import SelectInput from '@/Shared/SelectInput'
import TextInput from '@/Shared/TextInput'
import Button from '@/Shared/Button'

const QuizQuestionAnswerEditForm = () => {
  const { quiz, question, errors } = usePage()

  const [values, setValues] = useState({
    title: '',
    value: '',
    is_correct: 0,
  })

  function handleChange(e) {
    const key = e.target.name
    const value = e.target.value
    setValues(values => ({
      ...values,
      [key]: value,
    }))
  }

  function handleSubmit(e) {
    e.preventDefault()
    Inertia.post(
      route('eventpal.quiz.questions.answers.store', [quiz, question]),
      values,
    )
  }

  return (
    <div>
      <form onSubmit={handleSubmit}>
        <div className='form-panel'>
          <div className=''>
            <TextInput
              className='pb-3'
              label='Title'
              name='title'
              errors={errors.title}
              value={values.title}
              onChange={handleChange}
            />
            <TextInput
              className='pb-3'
              label='Value'
              name='value'
              errors={errors.value}
              value={values.value}
              onChange={handleChange}
            />
            <SelectInput
              className='pb-3'
              label='Is Correct'
              name='is_correct'
              errors={errors.is_correct}
              value={values.is_correct}
              onChange={handleChange}
            >
              <option key='Yes' value='1'>
                Yes
              </option>
              <option key='No' value='0'>
                No
              </option>
            </SelectInput>
          </div>
        </div>
        <div className='page-actions'>
          <InertiaLink
            className='btn btn-light tw-float-left'
            href={route('eventpal.quiz.questions.answers.index', [
              quiz,
              question,
            ])}
          >
            <span>
              <i className='fas fa-chevron-left' />
              Back to Answer list
            </span>
          </InertiaLink>
          <Button
            type='submit'
            value='Submit'
            icon='fas fa-check'
            className='btn btn-dark tw-float-right'
          />
        </div>
      </form>
    </div>
  )
}

// eslint-disable-next-line react/display-name
QuizQuestionAnswerEditForm.layout = page => (
  <Layout area='Quizzes - Answer list' title='Edit Answer'>
    {page}
  </Layout>
)

export default QuizQuestionAnswerEditForm
