import React from 'react'
import { InertiaLink } from '@inertiajs/inertia-react'
import Layout from '@/Shared/Layout'

const QuizQuestionAnswer = data => {
  const answers = data.answers
  const question = data.question
  const quizId = data.quiz.id

  return (
    <div className='table-panel'>
      <div className='table-panel__header'>
        <InertiaLink
          className='btn btn-light tw-mr-3'
          href={route('eventpal.quiz.questions.index', quizId)}
        >
          <span>
            <i className='fas fa-chevron-left' />
            Back to Question list
          </span>
        </InertiaLink>

        <InertiaLink
          className='btn btn-dark'
          href={route('eventpal.quiz.questions.answers.create', [
            quizId,
            question,
          ])}
        >
          <span>
            <i className='fas fa-plus' />
            Create Answer
          </span>
        </InertiaLink>
      </div>

      <div className='table-panel__table'>
        <table className='table table-striped'>
          <thead>
            <tr>
              <th>Re-order</th>
              <th>#</th>
              <th>Answer title</th>
              <th>Responses</th>
              <th>Correct</th>
              <th>Actions</th>
            </tr>
          </thead>
          <tbody>
            {answers.map(answer => (
              <tr key={answer.id}>
                <td>
                  <a
                    className='action-button'
                    href='#'
                    title='TBC | Drag me to re-order'
                  >
                    <i className='fas fa-bars fa-lg' />
                  </a>
                </td>
                <td>{answer.id}</td>
                <td>{answer.title}</td>
                <td>{answer.responses}</td>
                <td>
                  {answer.isCorrect > 0 && (
                    <span className='badge badge-secondary'>
                      {answer.isCorrect} Correct
                    </span>
                  )}
                </td>
                <td>
                  <InertiaLink
                    className='action-button'
                    href={route('eventpal.quiz.questions.answers.edit', [
                      quizId,
                      question,
                      answer,
                    ])}
                    title='Edit answer'
                  >
                    <span>
                      <i className='fas fa-pencil-alt fa-lg' />
                    </span>
                  </InertiaLink>

                  <InertiaLink
                    className='action-button'
                    href={route('eventpal.quiz.questions.answers.destroy', [
                      quizId,
                      question,
                      answer,
                    ])}
                    title='Delete answer'
                  >
                    <span>
                      <i className='far fa-trash-alt fa-lg' />
                    </span>
                  </InertiaLink>
                </td>
              </tr>
            ))}
            {answers.length === 0 && (
              <tr>
                <td className='no-results' colSpan='4'>
                  No answers found
                </td>
              </tr>
            )}
          </tbody>
        </table>
      </div>
    </div>
  )
}

// eslint-disable-next-line react/display-name
QuizQuestionAnswer.layout = page => (
  <Layout area='Quizzes - Question list' title='Answer list'>
    {page}
  </Layout>
)

export default QuizQuestionAnswer
