<?php

namespace Drp\EventPalAdmin\Http\Requests;

use Drp\NativeEventApp\Enums\NotificationStatus;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rule;

class NotificationRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     */
    public function authorize(): bool
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules(): array
    {
        return [
            'event' => 'required',
            'title' => 'required|max:200',
            'message' => 'required|max:1000',
            'status' => 'required',
            'sendAt' => $this->buildSendAtRules(),
        ];
    }

    public function messages(): array
    {
        return [
            'event.required' => 'An event must be selected.',
            'segments.in' => 'The selected segment is invalid.',
            'title.required' => 'A title must be added.',
            'title.max' => 'A title may not be greater than 200 characters.',
            'message.required' => 'A message must be added.',
            'message.max' => 'A title may not be greater than 1000 characters.',
            'sendAt.date' => 'The send at must be a valid date',
            'sendAt.after' => 'The send at date cannot be in the past',
            'sendAt.required' => 'You must specify a send at date if the status is set to published and send now is '
                . 'not selected',
        ];
    }

    public function buildSendAtRules(): array
    {
        return [
            'nullable',
            'date',
            'after:now',
            Rule::requiredIf(function () {
                return $this->request->get('status', NotificationStatus::DRAFT) === NotificationStatus::PUBLISHED
                    && $this->request->get('sendNow', 1) === 0;
            }),
        ];
    }
}
